@@ -1,5 +1,7 @@
 """CLI tests for tmuxp's core shell functionality."""
 
+from __future__ import annotations
+
 import argparse
 import contextlib
 import pathlib
@@ -29,14 +31,32 @@ def test_creates_config_dir_not_exists(tmp_path: pathlib.Path) -> None:
     assert tmp_path.exists()
 
 
+class HelpTestFixture(t.NamedTuple):
+    """Test fixture for help command tests."""
+
+    test_id: str
+    cli_args: list[str]
+
+
+HELP_TEST_FIXTURES: list[HelpTestFixture] = [
+    HelpTestFixture(
+        test_id="help_long_flag",
+        cli_args=["--help"],
+    ),
+    HelpTestFixture(
+        test_id="help_short_flag",
+        cli_args=["-h"],
+    ),
+]
+
+
 @pytest.mark.parametrize(
-    "cli_args",
-    [
-        (["--help"]),
-        (["-h"]),
-    ],
+    list(HelpTestFixture._fields),
+    HELP_TEST_FIXTURES,
+    ids=[test.test_id for test in HELP_TEST_FIXTURES],
 )
 def test_help(
+    test_id: str,
     cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
@@ -112,7 +132,7 @@ def test_pass_config_dir_argparse(
     def config_cmd(workspace_file: str) -> None:
         tmuxp_echo(find_workspace_file(workspace_file, workspace_dir=configdir))
 
-    def check_cmd(config_arg: str) -> "_pytest.capture.CaptureResult[str]":
+    def check_cmd(config_arg: str) -> _pytest.capture.CaptureResult[str]:
         args = parser.parse_args([config_arg])
         config_cmd(workspace_file=args.workspace_file)
         return capsys.readouterr()
@@ -130,7 +150,7 @@ def test_pass_config_dir_argparse(
 
 def test_reattach_plugins(
     monkeypatch_plugin_test_packages: None,
-    server: "Server",
+    server: Server,
 ) -> None:
     """Test reattach plugin hook."""
     config_plugins = test_utils.read_workspace_file("workspace/builder/plugin_r.yaml")
