@@ -1,5 +1,8 @@
 """Tmuxinator data fixtures for import_tmuxinator tests, 1st dataset."""
-from .. import utils as test_utils
+
+from __future__ import annotations
+
+from tests.fixtures import utils as test_utils
 
 tmuxinator_yaml = test_utils.read_workspace_file("import_tmuxinator/test1.yaml")
 tmuxinator_dict = {
